@@ -4,7 +4,7 @@ from .base import SwitchableDevice
 class LED(SwitchableDevice):
     """ LED control
 
-    -:param pin: The pin for control the LED
+    :param pin: The pin for control the LED
     """
     def __init__(self, pin, **kwargs):
         super().__init__(power=pin, **kwargs)
